@@ -22,6 +22,7 @@ from logging import DEBUG as _DEBUG
 from logging import WARNING as _WARNING
 from logging import getLogger
 from struct import unpack as _unpack
+from time import sleep as _sleep
 
 from . import hidpp20 as _hidpp20
 from .common import NamedInt as _NamedInt
@@ -419,7 +420,7 @@ class Settings(Setting):
                         return None
             return map
 
-    def write_key_value(self, key, value):
+    def write_key_value(self, key, value, save=True):
         assert hasattr(self, '_value')
         assert hasattr(self, '_device')
         assert key is not None
@@ -435,7 +436,7 @@ class Settings(Setting):
                 data_bytes = self._validator.prepare_write(int(key), value)
                 # always need to write to configuration because dictionary is shared and could have changed
                 self._value[int(key)] = value
-                self._pre_write()
+                self._pre_write(save)
             except ValueError:
                 data_bytes = value = None
             if data_bytes is not None:
@@ -520,7 +521,7 @@ class LongSettings(Setting):
                                 return None
             return map
 
-    def write_key_value(self, item, value):
+    def write_key_value(self, item, value, save=True):
         assert hasattr(self, '_value')
         assert hasattr(self, '_device')
         assert item is not None
@@ -534,7 +535,7 @@ class LongSettings(Setting):
                 self.read()
             data_bytes = self._validator.prepare_write_item(item, value)
             self._value[int(item)] = value
-            self._pre_write()
+            self._pre_write(save)
             if data_bytes is not None:
                 if _log.isEnabledFor(_DEBUG):
                     _log.debug('%s: settings prepare item value write(%s,%s) => %r', self.name, item, value, data_bytes)
@@ -618,7 +619,7 @@ class BitFieldSetting(Setting):
                         return None
             return map
 
-    def write_key_value(self, key, value):
+    def write_key_value(self, key, value, save=True):
         assert hasattr(self, '_value')
         assert hasattr(self, '_device')
         assert key is not None
@@ -632,7 +633,7 @@ class BitFieldSetting(Setting):
                 self.read()
             value = bool(value)
             self._value[int(key)] = value
-            self._pre_write()
+            self._pre_write(save)
 
             data_bytes = self._validator.prepare_write(self._value)
             if data_bytes is not None:
@@ -709,7 +710,7 @@ class RangeFieldSetting(Setting):
                 _log.warn('%s: range field setting no data to write', self.name)
             return map
 
-    def write_key_value(self, key, value):
+    def write_key_value(self, key, value, save=True):
         assert key is not None
         assert value is not None
         if _log.isEnabledFor(_DEBUG):
@@ -719,7 +720,7 @@ class RangeFieldSetting(Setting):
                 self.read()
             map = self._value
             map[int(key)] = value
-            self.write(map)
+            self.write(map, save)
             return value
 
 
@@ -1447,12 +1448,13 @@ class RawXYProcessing:
 
     def start(self, key):
         device_key = next((k for k in self.device.keys if k.key == key), None)
-        self.keys.append(device_key)
-        if not self.active:
-            self.active = True
-            self.activate_action()
-            self.device.add_notification_handler(self.name, self.handler)
-        device_key.set_rawXY_reporting(True)
+        if device_key:
+            self.keys.append(device_key)
+            if not self.active:
+                self.active = True
+                self.activate_action()
+                self.device.add_notification_handler(self.name, self.handler)
+            device_key.set_rawXY_reporting(True)
 
     def stop(self, key):  # only stop if this is the active key
         if self.active:
@@ -1489,6 +1491,8 @@ class RawXYProcessing:
 
 
 def apply_all_settings(device):
+    if device.features and _hidpp20.FEATURE.HIRES_WHEEL in device.features:
+        _sleep(0.2)  # delay to try to get out of race condition with Linux HID++ driver
     persister = getattr(device, 'persister', None)
     sensitives = persister.get('_sensitive', {}) if persister else {}
     for s in device.settings:
